@@ -12,18 +12,24 @@ utilizados durante a execução dos testes.
 # Importando bibliotecas
 import pytest
 import boto3
-from moto import mock_s3
+from moto import mock_s3, mock_secretsmanager
 
 from cloudgeass.aws.s3 import list_buckets, bucket_objects_report,\
     all_buckets_objects_report, read_s3_object
 
 from tests.configs.inputs import MOCKED_REGION, MOCKED_BUCKET_CONTENT,\
-    EXAMPLE_BUCKET
+    EXAMPLE_BUCKET, MOCKED_SECRET_NAME, MOCKED_SECRET_VALUE
+
+
+"""---------------------------------------------------
+-------- 1. DEFINIÇÃO DE FIXTURES DE MÓDULOS ---------
+         1.1 Fixtures gerais e de preparação
+---------------------------------------------------"""
 
 
 # Definindo resource s3 para operações de mock
 @pytest.fixture()
-def mocked_resource():
+def s3_resource():
     with mock_s3():
         resource = boto3.resource("s3", region_name=MOCKED_REGION)
         return resource
@@ -31,24 +37,32 @@ def mocked_resource():
 
 # Definindo client s3 para operações de mock
 @pytest.fixture()
-def mocked_client():
+def s3_client():
     with mock_s3():
         client = boto3.client("s3", region_name=MOCKED_REGION)
         return client
 
 
+# Definindo client do secrets manager para operações de mock
+@pytest.fixture()
+def sm_client():
+    with mock_secretsmanager():
+        client = boto3.client("secretsmanager", region_name=MOCKED_REGION)
+        return client
+
+
 # Retornando função como fixture para preparação de bucket mockado
 @pytest.fixture()
-def prepare_mocked_bucket(mocked_resource, mocked_client):
+def prepare_mocked_bucket(s3_resource, s3_client):
     def create_elements():
         # Iterando por dicionário de definição de mock no s3
         for bucket_name, content_definition in MOCKED_BUCKET_CONTENT.items():
             # Criando bucket s3 definido no dicionário
-            mocked_resource.create_bucket(Bucket=bucket_name)
+            s3_resource.create_bucket(Bucket=bucket_name)
 
             # Iterando por definição de conteúdo para upload de objetos
             for _, content in content_definition.items():
-                mocked_client.put_object(
+                s3_client.put_object(
                     Bucket=bucket_name,
                     Body=content["Body"],
                     Key=content["Key"]
@@ -57,45 +71,58 @@ def prepare_mocked_bucket(mocked_resource, mocked_client):
     return create_elements
 
 
+# Retornando função como fixture para preparação de segredos mockados
+@pytest.fixture()
+def prepare_mocked_secrets(sm_client):
+    def create_secret():
+        # Criando novo segredo
+        sm_client.create_secret(
+            Name=MOCKED_SECRET_NAME,
+            SecretString=MOCKED_SECRET_VALUE
+        )
+
+    return create_secret
+
+
 """---------------------------------------------------
--------- 2. DEFINIÇÃO DE FIXTURES DE MÓDULOS ---------
-       2.1 Funcionalidades do módulo test_s3.py
+-------- 1. DEFINIÇÃO DE FIXTURES DE MÓDULOS ---------
+       1.2 Funcionalidades do módulo test_s3.py
 ---------------------------------------------------"""
 
 
 # Lista resultante da função list_buckets()
 @pytest.fixture()
 @mock_s3
-def bucket_list(mocked_client, prepare_mocked_bucket):
+def bucket_list(s3_client, prepare_mocked_bucket):
     # Preparando ambiente mockado no s3
     prepare_mocked_bucket()
 
     # Gerando lista de buckets mockados no ambiente
-    return list_buckets(client=mocked_client)
+    return list_buckets(client=s3_client)
 
 
 # DataFrame resultante da função bucket_objects_report()
 @pytest.fixture()
 @mock_s3
-def df_objects_report(mocked_client, prepare_mocked_bucket):
+def df_objects_report(s3_client, prepare_mocked_bucket):
     # Preparando ambiente mockado no s3
     prepare_mocked_bucket()
 
     # Gerando DataFrame com report de objetos
     return bucket_objects_report(
-        bucket_name=EXAMPLE_BUCKET, client=mocked_client
+        bucket_name=EXAMPLE_BUCKET, client=s3_client
     )
 
 
 # DataFrame resultante da função all_buckets_objects_report()
 @pytest.fixture()
 @mock_s3
-def df_all_buckets_objects(mocked_client, prepare_mocked_bucket):
+def df_all_buckets_objects(s3_client, prepare_mocked_bucket):
     # Preparando ambiente mockado no s3
     prepare_mocked_bucket()
 
     # Gerando DataFrame com report de objetos de todos os buckets
-    return all_buckets_objects_report(client=mocked_client)
+    return all_buckets_objects_report(client=s3_client)
 
 
 # DataFrame resultante de leitura de objeto CSV via read_s3_object()
